@@ -4,6 +4,7 @@ import logging
 import numbers
 import os
 import pathlib
+from collections import defaultdict
 from enum import Enum
 from typing import Any, Dict, List, Union
 
@@ -79,7 +80,7 @@ class MetricManager:
 
     def __init__(
         self,
-        metric_set: Dict[str, str] = None,
+        metric_set: Dict[str, Any] = None,
         dimension_set: Dict = None,
         namespace: str = None,
         metadata_set: Dict[str, Any] = None,
@@ -93,7 +94,7 @@ class MetricManager:
         self._metric_unit_options = list(MetricUnit.__members__)
         self.metadata_set = self.metadata_set if metadata_set is not None else {}
 
-    def add_metric(self, name: str, unit: MetricUnit, value: Union[float, int]):
+    def add_metric(self, name: str, unit: Union[MetricUnit, str], value: float):
         """Adds given metric
 
         Example
@@ -110,7 +111,7 @@ class MetricManager:
         ----------
         name : str
             Metric name
-        unit : MetricUnit
+        unit : Union[MetricUnit, str]
             `aws_lambda_powertools.helper.models.MetricUnit`
         value : float
             Metric value
@@ -124,7 +125,9 @@ class MetricManager:
             raise MetricValueError(f"{value} is not a valid number")
 
         unit = self.__extract_metric_unit_value(unit=unit)
-        metric = {"Unit": unit, "Value": float(value)}
+        metric: Dict = self.metric_set.get(name, defaultdict(list))
+        metric["Unit"] = unit
+        metric["Value"].append(float(value))
         logger.debug(f"Adding metric: {name} with {metric}")
         self.metric_set[name] = metric
 
@@ -146,6 +149,8 @@ class MetricManager:
             Dictionary of metrics to serialize, by default None
         dimensions : Dict, optional
             Dictionary of dimensions to serialize, by default None
+        metadata: Dict, optional
+            Dictionary of metadata to serialize, by default None
 
         Example
         -------
@@ -177,13 +182,13 @@ class MetricManager:
         if self.service and not self.dimension_set.get("service"):
             self.dimension_set["service"] = self.service
 
-        logger.debug("Serializing...", {"metrics": metrics, "dimensions": dimensions})
+        logger.debug({"details": "Serializing metrics", "metrics": metrics, "dimensions": dimensions})
 
         metric_names_and_units: List[Dict[str, str]] = []  # [ { "Name": "metric_name", "Unit": "Count" } ]
-        metric_names_and_values: Dict[str, str] = {}  # { "metric_name": 1.0 }
+        metric_names_and_values: Dict[str, float] = {}  # { "metric_name": 1.0 }
 
         for metric_name in metrics:
-            metric: str = metrics[metric_name]
+            metric: dict = metrics[metric_name]
             metric_value: int = metric.get("Value", 0)
             metric_unit: str = metric.get("Unit", "")
 
@@ -207,7 +212,7 @@ class MetricManager:
         }
 
         try:
-            logger.debug("Validating serialized metrics against CloudWatch EMF schema", embedded_metrics_object)
+            logger.debug("Validating serialized metrics against CloudWatch EMF schema")
             fastjsonschema.validate(definition=CLOUDWATCH_EMF_SCHEMA, data=embedded_metrics_object)
         except fastjsonschema.JsonSchemaException as e:
             message = f"Invalid format. Error: {e.message}, Invalid item: {e.name}"  # noqa: B306, E501
@@ -257,7 +262,7 @@ class MetricManager:
 
         Parameters
         ----------
-        name : str
+        key : str
             Metadata key
         value : any
             Metadata value
